@@ -15,16 +15,25 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Any, Callable, Dict, Optional, Union
+from __future__ import annotations
 
+import asyncio
+from typing import TYPE_CHECKING, Any, Callable
+
+import aiohttp
 import requests
 import tenacity
+from aiohttp import ClientResponseError
+from asgiref.sync import sync_to_async
 from requests.auth import HTTPBasicAuth
 from requests_toolbelt.adapters.socket_options import TCPKeepAliveAdapter
 
 from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 
+if TYPE_CHECKING:
+    from aiohttp.client_reqrep import ClientResponse
+
 
 class HttpHook(BaseHook):
     """
@@ -40,18 +49,19 @@ class HttpHook(BaseHook):
     :param tcp_keep_alive_count: The TCP Keep Alive count parameter (corresponds to ``socket.TCP_KEEPCNT``)
     :param tcp_keep_alive_interval: The TCP Keep Alive interval parameter (corresponds to
         ``socket.TCP_KEEPINTVL``)
+    :param auth_args: extra arguments used to initialize the auth_type if different than default HTTPBasicAuth
     """
 
-    conn_name_attr = 'http_conn_id'
-    default_conn_name = 'http_default'
-    conn_type = 'http'
-    hook_name = 'HTTP'
+    conn_name_attr = "http_conn_id"
+    default_conn_name = "http_default"
+    conn_type = "http"
+    hook_name = "HTTP"
 
     def __init__(
         self,
-        method: str = 'POST',
+        method: str = "POST",
         http_conn_id: str = default_conn_name,
-        auth_type: Any = HTTPBasicAuth,
+        auth_type: Any = None,
         tcp_keep_alive: bool = True,
         tcp_keep_alive_idle: int = 120,
         tcp_keep_alive_count: int = 20,
@@ -62,15 +72,23 @@ class HttpHook(BaseHook):
         self.method = method.upper()
         self.base_url: str = ""
         self._retry_obj: Callable[..., Any]
-        self.auth_type: Any = auth_type
+        self._auth_type: Any = auth_type
         self.tcp_keep_alive = tcp_keep_alive
         self.keep_alive_idle = tcp_keep_alive_idle
         self.keep_alive_count = tcp_keep_alive_count
         self.keep_alive_interval = tcp_keep_alive_interval
 
+    @property
+    def auth_type(self):
+        return self._auth_type or HTTPBasicAuth
+
+    @auth_type.setter
+    def auth_type(self, v):
+        self._auth_type = v
+
     # headers may be passed through directly or in the "extra" field in the connection
     # definition
-    def get_conn(self, headers: Optional[Dict[Any, Any]] = None) -> requests.Session:
+    def get_conn(self, headers: dict[Any, Any] | None = None) -> requests.Session:
         """
         Returns http session for use with requests
 
@@ -93,11 +111,13 @@ class HttpHook(BaseHook):
                 self.base_url = self.base_url + ":" + str(conn.port)
             if conn.login:
                 session.auth = self.auth_type(conn.login, conn.password)
+            elif self._auth_type:
+                session.auth = self.auth_type()
             if conn.extra:
                 try:
                     session.headers.update(conn.extra_dejson)
                 except TypeError:
-                    self.log.warning('Connection to %s has invalid extra field.', conn.host)
+                    self.log.warning("Connection to %s has invalid extra field.", conn.host)
         if headers:
             session.headers.update(headers)
 
@@ -105,10 +125,10 @@ class HttpHook(BaseHook):
 
     def run(
         self,
-        endpoint: Optional[str] = None,
-        data: Optional[Union[Dict[str, Any], str]] = None,
-        headers: Optional[Dict[str, Any]] = None,
-        extra_options: Optional[Dict[str, Any]] = None,
+        endpoint: str | None = None,
+        data: dict[str, Any] | str | None = None,
+        headers: dict[str, Any] | None = None,
+        extra_options: dict[str, Any] | None = None,
         **request_kwargs: Any,
     ) -> Any:
         r"""
@@ -134,10 +154,10 @@ class HttpHook(BaseHook):
                 idle=self.keep_alive_idle, count=self.keep_alive_count, interval=self.keep_alive_interval
             )
             session.mount(url, keep_alive_adapter)
-        if self.method == 'GET':
+        if self.method == "GET":
             # GET uses params
             req = requests.Request(self.method, url, params=data, headers=headers, **request_kwargs)
-        elif self.method == 'HEAD':
+        elif self.method == "HEAD":
             # HEAD doesn't use params
             req = requests.Request(self.method, url, headers=headers, **request_kwargs)
         else:
@@ -145,7 +165,7 @@ class HttpHook(BaseHook):
             req = requests.Request(self.method, url, data=data, headers=headers, **request_kwargs)
 
         prepped_request = session.prepare_request(req)
-        self.log.info("Sending '%s' to url: %s", self.method, url)
+        self.log.debug("Sending '%s' to url: %s", self.method, url)
         return self.run_and_check(session, prepped_request, extra_options)
 
     def check_response(self, response: requests.Response) -> None:
@@ -166,7 +186,7 @@ class HttpHook(BaseHook):
         self,
         session: requests.Session,
         prepped_request: requests.PreparedRequest,
-        extra_options: Dict[Any, Any],
+        extra_options: dict[Any, Any],
     ) -> Any:
         """
         Grabs extra options like timeout and actually runs the request,
@@ -189,7 +209,7 @@ class HttpHook(BaseHook):
         )
 
         # Send the request.
-        send_kwargs: Dict[str, Any] = {
+        send_kwargs: dict[str, Any] = {
             "timeout": extra_options.get("timeout"),
             "allow_redirects": extra_options.get("allow_redirects", True),
         }
@@ -198,15 +218,15 @@ class HttpHook(BaseHook):
         try:
             response = session.send(prepped_request, **send_kwargs)
 
-            if extra_options.get('check_response', True):
+            if extra_options.get("check_response", True):
                 self.check_response(response)
             return response
 
         except requests.exceptions.ConnectionError as ex:
-            self.log.warning('%s Tenacity will retry to execute the operation', ex)
+            self.log.warning("%s Tenacity will retry to execute the operation", ex)
             raise ex
 
-    def run_with_advanced_retry(self, _retry_args: Dict[Any, Any], *args: Any, **kwargs: Any) -> Any:
+    def run_with_advanced_retry(self, _retry_args: dict[Any, Any], *args: Any, **kwargs: Any) -> Any:
         """
         Runs Hook.run() with a Tenacity decorator attached to it. This is useful for
         connectors which might be disturbed by intermittent issues and should not
@@ -231,16 +251,170 @@ class HttpHook(BaseHook):
 
         return self._retry_obj(self.run, *args, **kwargs)
 
-    def url_from_endpoint(self, endpoint: Optional[str]) -> str:
+    def url_from_endpoint(self, endpoint: str | None) -> str:
         """Combine base url with endpoint"""
-        if self.base_url and not self.base_url.endswith('/') and endpoint and not endpoint.startswith('/'):
-            return self.base_url + '/' + endpoint
-        return (self.base_url or '') + (endpoint or '')
+        if self.base_url and not self.base_url.endswith("/") and endpoint and not endpoint.startswith("/"):
+            return self.base_url + "/" + endpoint
+        return (self.base_url or "") + (endpoint or "")
 
     def test_connection(self):
         """Test HTTP Connection"""
         try:
             self.run()
-            return True, 'Connection successfully tested'
+            return True, "Connection successfully tested"
         except Exception as e:
             return False, str(e)
+
+
+class HttpAsyncHook(BaseHook):
+    """
+    Interact with HTTP servers using Python Async.
+
+    :param method: the API method to be called
+    :param http_conn_id: http connection id that has the base
+        API url i.e https://www.google.com/ and optional authentication credentials. Default
+        headers can also be specified in the Extra field in json format.
+    :param auth_type: The auth type for the service
+    """
+
+    conn_name_attr = "http_conn_id"
+    default_conn_name = "http_default"
+    conn_type = "http"
+    hook_name = "HTTP"
+
+    def __init__(
+        self,
+        method: str = "POST",
+        http_conn_id: str = default_conn_name,
+        auth_type: Any = aiohttp.BasicAuth,
+        retry_limit: int = 3,
+        retry_delay: float = 1.0,
+    ) -> None:
+        self.http_conn_id = http_conn_id
+        self.method = method.upper()
+        self.base_url: str = ""
+        self._retry_obj: Callable[..., Any]
+        self.auth_type: Any = auth_type
+        if retry_limit < 1:
+            raise ValueError("Retry limit must be greater than equal to 1")
+        self.retry_limit = retry_limit
+        self.retry_delay = retry_delay
+
+    async def run(
+        self,
+        endpoint: str | None = None,
+        data: dict[str, Any] | str | None = None,
+        headers: dict[str, Any] | None = None,
+        extra_options: dict[str, Any] | None = None,
+    ) -> ClientResponse:
+        r"""
+        Performs an asynchronous HTTP request call
+
+        :param endpoint: the endpoint to be called i.e. resource/v1/query?
+        :param data: payload to be uploaded or request parameters
+        :param headers: additional headers to be passed through as a dictionary
+        :param extra_options: Additional kwargs to pass when creating a request.
+            For example, ``run(json=obj)`` is passed as ``aiohttp.ClientSession().get(json=obj)``
+        """
+        extra_options = extra_options or {}
+
+        # headers may be passed through directly or in the "extra" field in the connection
+        # definition
+        _headers = {}
+        auth = None
+
+        if self.http_conn_id:
+            conn = await sync_to_async(self.get_connection)(self.http_conn_id)
+
+            if conn.host and "://" in conn.host:
+                self.base_url = conn.host
+            else:
+                # schema defaults to HTTP
+                schema = conn.schema if conn.schema else "http"
+                host = conn.host if conn.host else ""
+                self.base_url = schema + "://" + host
+
+            if conn.port:
+                self.base_url = self.base_url + ":" + str(conn.port)
+            if conn.login:
+                auth = self.auth_type(conn.login, conn.password)
+            if conn.extra:
+                try:
+                    _headers.update(conn.extra_dejson)
+                except TypeError:
+                    self.log.warning("Connection to %s has invalid extra field.", conn.host)
+        if headers:
+            _headers.update(headers)
+
+        if self.base_url and not self.base_url.endswith("/") and endpoint and not endpoint.startswith("/"):
+            url = self.base_url + "/" + endpoint
+        else:
+            url = (self.base_url or "") + (endpoint or "")
+
+        async with aiohttp.ClientSession() as session:
+            if self.method == "GET":
+                request_func = session.get
+            elif self.method == "POST":
+                request_func = session.post
+            elif self.method == "PATCH":
+                request_func = session.patch
+            elif self.method == "HEAD":
+                request_func = session.head
+            elif self.method == "PUT":
+                request_func = session.put
+            elif self.method == "DELETE":
+                request_func = session.delete
+            elif self.method == "OPTIONS":
+                request_func = session.options
+            else:
+                raise AirflowException(f"Unexpected HTTP Method: {self.method}")
+
+            attempt_num = 1
+            while True:
+                response = await request_func(
+                    url,
+                    json=data if self.method in ("POST", "PATCH") else None,
+                    params=data if self.method == "GET" else None,
+                    headers=headers,
+                    auth=auth,
+                    **extra_options,
+                )
+                try:
+                    response.raise_for_status()
+                    return response
+                except ClientResponseError as e:
+                    self.log.warning(
+                        "[Try %d of %d] Request to %s failed.",
+                        attempt_num,
+                        self.retry_limit,
+                        url,
+                    )
+                    if not self._retryable_error_async(e) or attempt_num == self.retry_limit:
+                        self.log.exception("HTTP error with status: %s", e.status)
+                        # In this case, the user probably made a mistake.
+                        # Don't retry.
+                        raise AirflowException(f"{e.status}:{e.message}")
+
+                attempt_num += 1
+                await asyncio.sleep(self.retry_delay)
+
+    def _retryable_error_async(self, exception: ClientResponseError) -> bool:
+        """
+        Determines whether or not an exception that was thrown might be successful
+        on a subsequent attempt.
+
+        It considers the following to be retryable:
+            - requests_exceptions.ConnectionError
+            - requests_exceptions.Timeout
+            - anything with a status code >= 500
+
+        Most retryable errors are covered by status code >= 500.
+        """
+        if exception.status == 429:
+            # don't retry for too Many Requests
+            return False
+        if exception.status == 413:
+            # don't retry for payload Too Large
+            return False
+
+        return exception.status >= 500
